@@ -49,7 +49,15 @@ def multifunc(data,axisref,deffunc):
     # dataouttrns = scandata(0,datatrns,array([]),trnsaxisref,deffunc)
     # 
     # create an array of correct dimension first to get performance increase
-    dataouttrns = zeros(getshapeout(datatrns,trnsaxisref,deffunc))
+    shapeout, typeout = getshapeout(datatrns,trnsaxisref,deffunc)
+    dataouttrns = zeros(shapeout)
+    # workaround to be able to work with datetimes
+    if typeout == 'datetime':
+        dataouttrns = [None]
+        for eshapeout in shapeout:
+            dataouttrns = dataouttrns*eshapeout
+        dataouttrns = array([dataouttrns])
+        dataouttrns.shape = shapeout
     scandata(datatrns,trnsaxisref,deffunc,dataouttrns)
 
     # # old version
@@ -62,34 +70,45 @@ def multifunc(data,axisref,deffunc):
     for itrns,etrns in enumerate(trns):
         inv[etrns] = itrns
     dataout = transpose(dataouttrns,inv)
-    print('shapedataout: ',shape(dataout))
 
     return dataout
 
 # get data shape
 def getshapeout(datain,axisref,deffunc,dimidx=0):
-    if ((axisref[dimidx] == False) & (dimidx <= (len(shape(datain))))):
+    iterate = False
+    if (dimidx <= (len(shape(datain)))):
+        if (axisref[dimidx] == False):
+            iterate = True
+    if iterate == True:
         axidx = 0
-        shapeout = getshapeout(datain[0],axisref,deffunc,dimidx = dimidx+1)
+        shapeout,typeout = getshapeout(datain[0],axisref,deffunc,dimidx = dimidx+1)
         shapeout.insert(0,datain.shape[0])
+        dataout = None
     else:
-        dataout = deffunc(datain[:])
-        if ((type(dataout).__name__ == 'list') or (type(dataout).__name__ == 'tuple')):
+        dataout = deffunc(datain)
+        typeout = type(dataout).__name__
+        if ((typeout == 'list') or (typeout == 'tuple')):
             dataout = dataout[0]
         shapeout = list(shape(dataout))
-    return shapeout
+    return (shapeout, typeout)
 
 def scandata(datain,axisref,deffunc,dataout,dimidx=0):
-    if ((axisref[dimidx] == False) & (dimidx <= (len(shape(datain))))):
+    iterate = False
+    if (dimidx <= (len(shape(datain)))):
+        if (axisref[dimidx] == False):
+            iterate = True
+
+    if iterate:
         # get shape of nested dataout
         for axidx in range(datain.shape[0]):
-            scandata(datain[axidx],axisref,deffunc,dataout[axidx],dimidx = dimidx+1)
+            dataout[axidx] = scandata(datain[axidx],axisref,deffunc,dataout[axidx],dimidx = dimidx+1)
     else:
-        dataouttemp= deffunc(datain[:])
+        dataouttemp= deffunc(datain)
         if ((type(dataouttemp).__name__ == 'list') or (type(dataouttemp).__name__ == 'tuple')):
-            dataout[:] = dataouttemp[0]
+            dataout = dataouttemp[0]
         else:
-            dataout[:] = dataouttemp
+            dataout = dataouttemp
+    return dataout
 
 
 #for eshape in shape(datain):
