@@ -44,7 +44,7 @@ def avgcycle(data, timeco = None, timewarp = None, cclose=False):
                 if (edata == None):
                     edata = nan
 
-            dataout.append(mean(datacosel(data,cocosel = tempcosel)[0]))
+            dataout.append(mean(tdatacosel))
             timecoout.append(timeco[idata])
             #dataout.append(mean(scisel(data,timeco,tempco2) )
     
